Attribute VB_Name = "modINI"

' Declarations for Windows INI File Manipulation procedures
Private Declare Function GetPrivateProfileInt Lib "kernel32" Alias "GetPrivateProfileIntA" (ByVal strSection As String, ByVal strKeyName As String, ByVal lngDefault As Long, ByVal strFileName As String) As Long
Private Declare Function GetPrivateProfileString Lib "kernel32" Alias "GetPrivateProfileStringA" (ByVal strSection As String, ByVal strKeyName As String, ByVal strDefault As String, ByVal strReturned As String, ByVal lngSize As Long, ByVal strFileName As String) As Long
Private Declare Function WinHelp Lib "USER32" Alias "WinHelpA" (ByVal hwnd As Long, ByVal lpHelpFile As String, ByVal wCommand As Long, ByVal dwData As Long) As Long
Private Declare Function WritePrivateProfileString Lib "kernel32" Alias "WritePrivateProfileStringA" (ByVal strSection As String, ByVal strKeyNam As String, ByVal strValue As String, ByVal strFileName As String) As Long

' API Calls to work with WIN.INI
Private Declare Function GetProfileInt Lib "kernel32" Alias "GetProfileIntA" (ByVal strSection As String, ByVal strKeyName As String, ByVal lngDefault As Long) As Integer
Private Declare Function GetProfileString Lib "kernel32" Alias "GetProfileStringA" (ByVal strSection As String, ByVal strKeyName As String, ByVal strDefault As String, ByVal strReturned As String, ByVal intSize As Long) As Long
Private Declare Function WriteProfileString Lib "kernel32" Alias "WriteProfileStringA" (ByVal strSection As String, ByVal strKeyName As String, ByVal strValue As String) As Integer

Public sINIFile  As String

Public Function INIGetSettingInteger(strSection As String, strKeyName As String, strFile As String) As Integer
' Comments  : Returns an integer value from the specified INI file
' Parameters: strSection - Name of the section to look in
'             strKeyName - Name of the key to look for
'             strFile - Path and name of the INI file to look in
' Returns   : Integer value

Dim intValue As Integer
On Error GoTo PROC_ERR

    intValue = GetPrivateProfileInt(strSection, strKeyName, 0, strFile)

    INIGetSettingInteger = intValue

PROC_EXIT:
Exit Function

PROC_ERR:
    MsgBox "Error: " & Err.Number & ". " & Err.Description, vbSystemModal, "INIGetSettingInteger"
Resume PROC_EXIT

End Function

Public Function INIGetSettingString(strSection As String, strKeyName As String, strFile As String) As String
  ' Comments  : Returns a string value from the specified INI file
  ' Parameters: strSection - Name of the section to look in
  '             strKeyName - Name of the key to look for
  '             strFile - Path and name of the INI file to look in
  ' Returns   : String value
  ' Source    :
  '
Dim strBuffer As String * 256
Dim intSize As Integer
On Error GoTo PROC_ERR
  
    intSize = GetPrivateProfileString(strSection, strKeyName, "", strBuffer, 256, strFile)
    
    INIGetSettingString = Left$(strBuffer, intSize)
    
PROC_EXIT:
  Exit Function
  
PROC_ERR:
  MsgBox "Error: " & Err.Number & ". " & Err.Description, vbSystemModal, _
    "INIGetSettingString"
  Resume PROC_EXIT
  
End Function

Public Function INIWriteSetting(strSection As String, strKeyName As String, strValue As String, strFile As String) As Integer
  ' Comments  : Writes the specified value to the specified INI file
  ' Parameters: strSection - section to write into
  '             strKeyName - key to write into
  '             strValue - value to write
  '             strFile - path and name of the INI file to write to
  ' Returns   : True if successful, False otherwise
  
Dim intStatus As Integer
On Error GoTo PROC_ERR
  
    intStatus = WritePrivateProfileString(strSection, strKeyName, strValue, strFile)
    INIWriteSetting = (intStatus <> 0)

PROC_EXIT:
  Exit Function
  
PROC_ERR:
  MsgBox "Error: " & Err.Number & ". " & Err.Description, vbSystemModal, _
    "INIWriteSetting"
  Resume PROC_EXIT
  
End Function

Public Function WinINIGetSettingInteger(strSection As String, strKeyName As String) As Integer
  ' Comments  : Returns an integer value from WIN.INI
  ' Parameters: strSection - name of the section to look in
  '             strKeyName - name of the key to look for
  ' Returns   : integer value
  ' Source    :
  '
  Dim intValue As Integer

  On Error GoTo PROC_ERR
  
  intValue = GetProfileInt(strSection, strKeyName, 0)
  WinINIGetSettingInteger = intValue

PROC_EXIT:
  Exit Function
  
PROC_ERR:
  MsgBox "Error: " & Err.Number & ". " & Err.Description, vbSystemModal, _
    "WinINIGetSettingInteger"
  Resume PROC_EXIT
  
End Function

Public Function WinINIGetSettingString(strSection As String, strKeyName As String) As String
  ' Comments  : Returns a string value from the WIN.INI file
  ' Parameters: strSection - name of the section to look in
  '             strKeyName - name of the key to look for
  ' Returns   : string value
  
  Dim strBuffer As String * 256
  Dim intSize As Integer

  intSize = GetProfileString(strSection, strKeyName, "", strBuffer, 256)

  WinINIGetSettingString = Left$(strBuffer, intSize)

PROC_EXIT:
  Exit Function
  
PROC_ERR:
  MsgBox "Error: " & Err.Number & ". " & Err.Description, vbSystemModal, "WinINIGetSettingString"
  Resume PROC_EXIT
  
End Function

Public Function WinINIWriteSetting(strSection As String, strKeyName As String, strValue As String) As Integer
  ' Comments  : Writes the specified value to WIN.INI
  ' Parameters: strSection - section to write into
  '             strKeyName - key to write into
  '             strValue - value to write
  ' Returns   : True if successful, False otherwise
  ' Source    :
  '
  Dim intStatus As Integer

  On Error GoTo PROC_ERR
  
  intStatus = WriteProfileString(strSection, strKeyName, strValue)

  WinINIWriteSetting = (intStatus <> 0)

PROC_EXIT:
  Exit Function
  
PROC_ERR:
  MsgBox "Error: " & Err.Number & ". " & Err.Description, vbSystemModal, "WinINIWriteSetting"
  Resume PROC_EXIT
  
End Function
